/*
 * Copyright (C) 2007
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Inspired by Rosimildo da Silva's work.
 *	rdasilva@connecttel.com
 *	http://www.connecttel.com
 */

#include <bsp.h>

#include <rtems/fb.h>
#include <rtems/console.h>
#include <rtems/clockdrv.h>
#include <rtems/touchscreen.h>

/*
 * XXX comment this line to disable lcd screen swapping.
 */

#define SWAP_LCD

/* functions */
#ifdef __cplusplus
extern "C" {
#endif

/* configuration information */
#define CONFIGURE_MAXIMUM_DEVICES                     40
#define CONFIGURE_MAXIMUM_TASKS                       100
#define CONFIGURE_MAXIMUM_TIMERS                      32
#define CONFIGURE_MAXIMUM_SEMAPHORES                  100
#define CONFIGURE_MAXIMUM_MESSAGE_QUEUES              20
#define CONFIGURE_MAXIMUM_PARTITIONS                  100
#define CONFIGURE_MAXIMUM_REGIONS                     100

/* This seetings overwrite the ones defined in confdefs.h */
#define CONFIGURE_MAXIMUM_POSIX_MUTEXES               32
#define CONFIGURE_MAXIMUM_POSIX_CONDITION_VARIABLES   32
#define CONFIGURE_MAXIMUM_POSIX_KEYS                  32
#define CONFIGURE_MAXIMUM_POSIX_QUEUED_SIGNALS        10
#define CONFIGURE_MAXIMUM_POSIX_THREADS               128
#define CONFIGURE_MAXIMUM_POSIX_TIMERS                10
#define CONFIGURE_LIBIO_MAXIMUM_FILE_DESCRIPTORS      200

/* used by the input device driver */
#define CONFIGURE_MAXIMUM_POSIX_MESSAGE_QUEUES        20

void *POSIX_Init( void *argument );
#define CONFIGURE_POSIX_INIT_THREAD_STACK_SIZE        (384*1024)
#define CONFIGURE_POSIX_INIT_THREAD_TABLE

#define CONFIGURE_HAS_OWN_DEVICE_DRIVER_TABLE

rtems_driver_address_table Device_drivers[] =
{
  CONSOLE_DRIVER_TABLE_ENTRY,
  CLOCK_DRIVER_TABLE_ENTRY,

  FB_DRIVER_TABLE_ENTRY,
  TOUCHSCREEN_DRIVER_TABLE_ENTRY,

  { NULL,NULL, NULL,NULL,NULL, NULL }
};



#include <rtems/confdefs.h>

#ifdef __cplusplus
}
#endif
/* end of include file */
