#!/bin/sh

if [ "${TESTSUITE}" == "" ]; then
    TESTSUITE=sptests
fi

RTEMS_SRC=/home/buckman/rtems/rtems
RTEMS_BUILD=/home/buckman/rtems/rtems/buildtmp/arm-rtems4.8/c/nds

FULL_REPORT=`pwd`/report.log

nb_ok=0
nb_failed=0

rm -f ${FULL_REPORT} 2> /dev/null

cd /tmp

TESTS=`find ${RTEMS_SRC}/testsuites -name '*.scn' | grep ${TESTSUITE} | sort -u`

for i in ${TESTS}; do
    TEST_ID=`basename ${i} .scn`
    TEST_DIR=`dirname ${i}`
    TEST_SUBDIR=`echo -n ${TEST_DIR} | cut -c \`echo -n ${RTEMS_SRC}/testsuites/ | wc -c\`-`

    echo "processing ${TEST_ID}..." | tee -a ${FULL_REPORT}

    rm -f debug.log ref out > /dev/null

    desmume-cli ${RTEMS_BUILD}/testsuites/${TEST_SUBDIR}/${TEST_ID}.nds 2>&1 > /dev/null

    TEST_REF=${i}
    j=`grep -n '*** END' ${TEST_REF} | cut -d':' -f1`
    head -${j} ${TEST_REF} > ref

    j=`grep -n '\*\*\* ' debug.log | head -1 | cut -d':' -f1`
    k=`wc -l debug.log | cut -d' ' -f1`

    tail -$((k-j+1)) debug.log | head -$((k-j))| sed 's/\r//g' > out

    diff -uwbB ref out >> ${FULL_REPORT}

    if [ "$?" -ne 0 ]; then
	echo -e "test ${TEST_ID} \e[0;31mfailed\e[m"
	nb_failed=$((nb_failed+1))
    else
	echo -e "test ${TEST_ID} \e[0;32mok\e[m"
	nb_ok=$((nb_ok+1))
    fi

done

echo "${nb_ok} test(s) passed, ${nb_failed} test(s) failed"
